@@ -17,9 +17,6 @@
 
 #define BIJIBEN_MAIN_WIN_TITLE N_("Notes")
 
-#define BJB_DEFAULT_FONT "Serif 10"
-
-
 enum {
   PROP_0,
   PROP_NOTE,
@@ -61,9 +58,6 @@ struct _BjbWindowBasePriv
   /* when a note is opened */
   BijiNoteObj          *note;
   gboolean              detached; // detached note
-
-
-  PangoFontDescription *font ;
 };
 
 /* Gobject */
@@ -271,11 +265,6 @@ bjb_window_base_constructed (GObject *obj)
 {
   BjbWindowBase *self = BJB_WINDOW_BASE (obj);
   BjbWindowBasePriv *priv;
-  const gchar *icons_path;
-  gchar *full_path;
-  GList *icons = NULL;
-  GdkPixbuf *bjb ;
-  GError *error = NULL;
   gboolean maximized;
   const gint32 *position;
   const gint32 *size;
@@ -311,34 +300,8 @@ bjb_window_base_constructed (GObject *obj)
   if (maximized)
     gtk_window_maximize (GTK_WINDOW (self));
 
-
-  /* Icon for window. TODO - Should be BjbApp */
-  icons_path = bijiben_get_bijiben_dir ();
-  full_path = g_build_filename (icons_path,
-                                "icons",
-                                "hicolor",
-                                "48x48",
-                                "apps",
-                                "bijiben.png",
-                                NULL);
-
-  bjb = gdk_pixbuf_new_from_file (full_path, &error);
-  g_free (full_path);
-
-  if ( error )
-  {
-    g_message("%s", error->message);
-    g_error_free(error);
-  }
-
-  icons = g_list_prepend(icons,bjb);
-  gtk_window_set_default_icon_list(icons);
-  g_list_foreach (icons, (GFunc) g_object_unref, NULL);
-  g_list_free (icons);
-
   /*  We probably want to offer a no entry window at first (startup) */
   priv->entry = NULL ;
-  priv->font = pango_font_description_from_string (BJB_DEFAULT_FONT);
 
   priv->controller = bjb_controller_new
     (bijiben_get_manager (BIJIBEN_APPLICATION(g_application_get_default())),
@@ -503,13 +466,6 @@ bjb_window_base_get_controller ( BjbWindowBase *window )
   return window->priv->controller ;
 }
 
-PangoFontDescription *
-window_base_get_font(GtkWidget *window)
-{
-  BjbWindowBase *b = BJB_WINDOW_BASE(window);
-  return b->priv->font ;
-}
-
 BijiNoteObj *
 bjb_window_base_get_note (BjbWindowBase *self)
 {
